%--------------------------------------------------------------------------
% File     : CIV002-1 : TPTP v2.2.0. Released v1.1.0.
% Domain   : Circuit Verification
% Problem  : Invert 3 inputs with 2 not gates
% Version  : [ANL] axioms : Reduced > Complete.
% English  : This is made to validate the circuit that inverts 3 inputs 
%            using as many AND and OR gates as you like, but using only 
%            two NOT gates.

% Refs     : [WO+92] Wos et al. (1992), Automated Reasoning: Introduction a
% Source   : [ANL]
% Names    : two.inverter.val.ver1.in [ANL]

% Status   : unsatisfiable
% Rating   : 1.00 v2.0.0
% Syntax   : Number of clauses    :   62 (   0 non-Horn;  51 unit;  38 RR)
%            Number of literals   :   76 (  68 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    2 (   0 propositional; 1-2 arity)
%            Number of functors   :   39 (  35 constant; 0-2 arity)
%            Number of variables  :   56 (   2 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : Some duplicate clauses have been removed from the [ANL] version.
%--------------------------------------------------------------------------
%----Include axioms of equality 
include('Axioms/EQU001-0.ax').
%----Include substitution axioms for AND, OR and NOT 
include('Axioms/CID001-0.eq').
%--------------------------------------------------------------------------
%----Substitution axioms 
input_clause(xor_substitution1,axiom,
    [--equal(O,P),
     ++equal(xor(O,Q),xor(P,Q))]).

input_clause(xor_substitution2,axiom,
    [--equal(R,S),
     ++equal(xor(T,R),xor(T,S))]).

input_clause(circuit_substitution1,axiom,
    [--equal(U,V),
     --circuit(U),
     ++circuit(V)]).

%----Canonicalizing an exclusive-or/and expression 
input_clause(xor_definition1,axiom,
    [++equal(xor(0,X),X)]).

input_clause(xor_definition2,axiom,
    [++equal(xor(X,0),X)]).

input_clause(xor_definition3,axiom,
    [++equal(xor(X,X),0)]).

input_clause(xor_simplification1,axiom,
    [++equal(xor(X,xor(X,Y)),Y)]).

input_clause(and_definition1,axiom,
    [++equal(and(0,X),0)]).

input_clause(and_definition2,axiom,
    [++equal(and(X,0),0)]).

input_clause(and_definition3,axiom,
    [++equal(and(1,X),X)]).

input_clause(and_definition4,axiom,
    [++equal(and(X,1),X)]).

input_clause(and_simplification1,axiom,
    [++equal(and(X,X),X)]).

input_clause(and_simplification2,axiom,
    [++equal(and(X,and(X,Y)),and(X,Y))]).

input_clause(and_xor_simplification,axiom,
    [++equal(and(X,xor(Y,Z)),xor(and(X,Y),and(X,Z)))]).

input_clause(not_to_xor,axiom,
    [++equal(not(X),xor(1,X))]).

input_clause(or_to_xor,axiom,
    [++equal(or(X,Y),xor(and(X,Y),xor(X,Y)))]).

%----Associativity and symmetry 
input_clause(xor_symmetry,conjecture,
    [++equal(xor(X,Y),xor(Y,X))]).

input_clause(xor_commutativity,conjecture,
    [++equal(xor(Y,xor(X,Z)),xor(X,xor(Y,Z)))]).

input_clause(and_symmetry,conjecture,
    [++equal(and(X,Y),and(Y,X))]).

input_clause(and_commutativity,conjecture,
    [++equal(and(Y,and(X,Z)),and(X,and(Y,Z)))]).

%----Problem clauses 
input_clause(constructor1,conjecture,
    [++equal(o1,13)]).

input_clause(constructor2,conjecture,
    [++equal(o2,17)]).

input_clause(constructor3,conjecture,
    [++equal(o3,5)]).

input_clause(constructor4,conjecture,
    [++equal(a1,and(inv1,i2))]).

input_clause(constructor5,conjecture,
    [++equal(2,and(inv1,i3))]).

input_clause(constructor6,conjecture,
    [++equal(3,or(a1,24))]).

input_clause(constructor7,conjecture,
    [++equal(4,or(15,3))]).

input_clause(constructor8,conjecture,
    [++equal(5,or(4,21))]).

input_clause(constructor9,conjecture,
    [++equal(6,and(i1,i2))]).

input_clause(constructor10,conjecture,
    [++equal(7,and(6,i3))]).

input_clause(constructor11,conjecture,
    [++equal(8,or(a1,10))]).

input_clause(constructor12,conjecture,
    [++equal(9,or(8,2))]).

input_clause(constructor13,conjecture,
    [++equal(10,or(24,7))]).

input_clause(constructor14,conjecture,
    [++equal(11,or(a1,2))]).

input_clause(constructor15,conjecture,
    [++equal(12,or(11,16))]).

input_clause(constructor16,conjecture,
    [++equal(13,or(12,21))]).

input_clause(constructor17,conjecture,
    [++equal(14,and(i2,i3))]).

input_clause(constructor18,conjecture,
    [++equal(15,and(inv2,6))]).

input_clause(constructor19,conjecture,
    [++equal(16,and(14,inv2))]).

input_clause(constructor20,conjecture,
    [++equal(17,or(18,21))]).

input_clause(constructor21,conjecture,
    [++equal(18,or(19,25))]).

input_clause(constructor22,conjecture,
    [++equal(19,and(23,inv2))]).

input_clause(constructor23,conjecture,
    [++equal(20,or(22,14))]).

input_clause(constructor24,conjecture,
    [++equal(21,and(inv1,inv2))]).

input_clause(constructor25,conjecture,
    [++equal(22,or(23,6))]).

input_clause(constructor26,conjecture,
    [++equal(23,and(i1,i3))]).

input_clause(constructor27,conjecture,
    [++equal(24,and(i1,inv1))]).

input_clause(constructor28,conjecture,
    [++equal(25,or(2,24))]).

input_clause(constructor29,conjecture,
    [++equal(inv1,not(20))]).

input_clause(constructor30,conjecture,
    [++equal(inv2,not(9))]).

input_clause(output1,conjecture,
    [++circuit(o1)]).

input_clause(output2,conjecture,
    [++circuit(o2)]).

input_clause(output3,conjecture,
    [++circuit(o3)]).

input_clause(prove_inversion,conjecture,
    [--circuit(not(i1)),
     --circuit(not(i2)),
     --circuit(not(i3))]).
%--------------------------------------------------------------------------
