%--------------------------------------------------------------------------
% File     : GEO043-3 : TPTP v2.2.0. Released v1.0.0.
% Domain   : Geometry
% Problem  : Corollary to first inner transitivity property of betweenness
% Version  : [Qua89] axioms : Augmented.
% English  : Corollary of first inner transitivity property of betweenness,
%            using symmetry.

% Refs     : [SST83] Schwabbauser et al. (1983), Metamathematische Methoden
%          : [Qua89] Quaife (1989), Automated Development of Tarski's Geome
% Source   : [Qua89]
% Names    : B5 [Qua89]

% Status   : unsatisfiable
% Rating   : 0.56 v2.2.0, 0.67 v2.1.0, 0.67 v2.0.0
% Syntax   : Number of clauses    :   92 (  11 non-Horn;  21 unit;  47 RR)
%            Number of literals   :  214 (  98 equality)
%            Maximal clause size  :    8 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-4 arity)
%            Number of functors   :   13 (   7 constant; 0-6 arity)
%            Number of variables  :  376 (  10 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include Tarski geometry axioms 
include('Axioms/GEO002-0.ax').
include('Axioms/GEO002-0.eq').
%----Include definition of reflection 
include('Axioms/GEO002-2.ax').
include('Axioms/GEO002-2.eq').
%--------------------------------------------------------------------------
input_clause(d1,axiom,
    [++equidistant(U,V,U,V)]).

input_clause(d2,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(W,X,U,V)]).

input_clause(d3,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(V,U,W,X)]).

input_clause(d4_1,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(U,V,X,W)]).

input_clause(d4_2,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(V,U,X,W)]).

input_clause(d4_3,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(W,X,V,U)]).

input_clause(d4_4,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(X,W,U,V)]).

input_clause(d4_5,axiom,
    [--equidistant(U,V,W,X),
     ++equidistant(X,W,V,U)]).

input_clause(d5,axiom,
    [--equidistant(U,V,W,X),
     --equidistant(W,X,Y,Z),
     ++equidistant(U,V,Y,Z)]).

input_clause(e1,axiom,
    [++equal(V,extension(U,V,W,W))]).

input_clause(b0,axiom,
    [--equal(Y,extension(U,V,W,X)),
     ++between(U,V,Y)]).

input_clause(r2_1,axiom,
    [++between(U,V,reflection(U,V))]).

input_clause(r2_2,axiom,
    [++equidistant(V,reflection(U,V),U,V)]).

input_clause(r3_1,axiom,
    [--equal(U,V),
     ++equal(V,reflection(U,V))]).

input_clause(r3_2,axiom,
    [++equal(U,reflection(U,U))]).

input_clause(r4,axiom,
    [--equal(V,reflection(U,V)),
     ++equal(U,V)]).

input_clause(d7,axiom,
    [++equidistant(U,U,V,V)]).

input_clause(d8,axiom,
    [--equidistant(U,V,U1,V1),
     --equidistant(V,W,V1,W1),
     --between(U,V,W),
     --between(U1,V1,W1),
     ++equidistant(U,W,U1,W1)]).

input_clause(d9,axiom,
    [--between(U,V,W),
     --between(U,V,X),
     --equidistant(V,W,V,X),
     ++equal(U,V),
     ++equal(W,X)]).

input_clause(d10_1,axiom,
    [--between(U,V,W),
     ++equal(U,V),
     ++equal(W,extension(U,V,V,W))]).

input_clause(d10_2,axiom,
    [--equidistant(W,X,Y,Z),
     ++equal(extension(U,V,W,X),extension(U,V,Y,Z)),
     ++equal(U,V)]).

input_clause(d10_3,axiom,
    [++equal(extension(U,V,U,V),extension(U,V,V,U)),
     ++equal(U,V)]).

input_clause(r5,axiom,
    [++equidistant(V,U,V,reflection(reflection(U,V),V))]).

input_clause(r6,axiom,
    [++equal(U,reflection(reflection(U,V),V))]).

input_clause(t3,axiom,
    [++between(U,V,V)]).

input_clause(b1,axiom,
    [--between(U,W,X),
     --equal(U,X),
     ++between(V,W,X)]).

input_clause(t1,axiom,
    [--between(U,V,W),
     ++between(W,V,U)]).

input_clause(t2,axiom,
    [++between(U,U,V)]).

input_clause(b2,axiom,
    [--between(U,V,W),
     --between(V,U,W),
     ++equal(U,V)]).

input_clause(b3,axiom,
    [--between(U,V,W),
     --between(U,W,V),
     ++equal(V,W)]).

input_clause(t6_1,axiom,
    [--between(U,V,W),
     --between(V,U,W),
     ++equal(U,V),
     ++equal(V,W)]).

input_clause(t6_2,axiom,
    [--between(U,V,W),
     --between(U,W,V),
     ++equal(U,V),
     ++equal(V,W)]).

input_clause(b4,axiom,
    [--between(U,V,W),
     --between(V,W,X),
     ++between(U,V,W)]).

input_clause(v_between_u_and_w,hypothesis,
    [++between(u,v,w)]).

input_clause(w_between_u_and_x,hypothesis,
    [++between(u,w,x)]).

input_clause(prove_w_between_v_and_x,conjecture,
    [--between(v,w,x)]).
%--------------------------------------------------------------------------
