%--------------------------------------------------------------------------
% File     : GRP024-4 : TPTP v2.2.0. Released v1.0.0.
% Domain   : Group Theory
% Problem  : Associativity of commutator
% Version  : [MOW76] (equality) axioms : Augmented.
% English  : The commutator operation is associative if and only if the 
%            commutator of any two elements lies in the center of the 
%            group, i.e. [[X,Y],Z]=[X,[Y,Z]] iff [U,V]*W=W*[U,V].

% Refs     : [Kur56] Kurosh (1956), The Theory of Groups
%          : [MOW76] McCharen et al. (1976), Problems and Experiments for a
%          : [ML92]  McCune & Lusk (1992), A Challenging Theorem of Levi
% Source   : [ML92]
% Names    : THEOREM (Levi) [ML92]

% Status   : unknown
% Rating   : 1.00 v2.0.0
% Syntax   : Number of clauses    :   16 (   1 non-Horn;   7 unit;   5 RR)
%            Number of literals   :   26 (  26 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :   10 (   7 constant; 0-2 arity)
%            Number of variables  :   29 (   0 singleton)
%            Maximal term depth   :    5 (   1 average)

% Comments : A textbook proof can be found in [Kur56].
%          : Uses an explicit formulation of the commutator
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%----Include group theory axioms 
include('Axioms/GRP004-0.ax').
%--------------------------------------------------------------------------
%----Redundant two axioms
input_clause(right_identity,axiom,
    [++equal(multiply(X,identity),X)]).

input_clause(right_inverse,axiom,
    [++equal(multiply(X,inverse(X)),identity)]).

%----Definition of the commutator 
input_clause(commutator,axiom,
    [++equal(commutator(X,Y),multiply(X,multiply(Y,multiply(inverse(X),
inverse(Y)))))]).

input_clause(commutator_substitutivity1,axiom,
    [--equal(A,B),
     ++equal(commutator(A,C),commutator(B,C))]).

input_clause(commutator_substitutivity2,axiom,
    [--equal(D,E),
     ++equal(commutator(F,D),commutator(F,E))]).

input_clause(associativity_or_center,conjecture,
    [++equal(commutator(commutator(a,b),c),commutator(a,
commutator(b,c))),
     ++equal(multiply(commutator(e,f),g),multiply(g,commutator(e,f)))]).

input_clause(not_both_associativity_and_center,conjecture,
    [--equal(commutator(commutator(a,b),c),commutator(a,
commutator(b,c))),
     --equal(multiply(commutator(e,f),g),multiply(g,commutator(e,f)))]).
%--------------------------------------------------------------------------
