%--------------------------------------------------------------------------
% File     : GRP039-7 : TPTP v2.2.0. Bugfixed v1.0.1.
% Domain   : Group Theory (Subgroups)
% Problem  : Subgroups of index 2 are normal
% Version  : [MOW76] (equality) axioms : Augmented.
% English  : If O is a subgroup of G and there are exactly 2 cosets 
%            in G/O, then O is normal [that is, for all x in G and 
%            y in O, x*y*inverse(x) is back in O].

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
% Source   : [MOW76]
% Names    : GP2 [MOW76]

% Status   : unsatisfiable
% Rating   : 0.44 v2.2.0, 0.67 v2.1.0, 0.89 v2.0.0
% Syntax   : Number of clauses    :   25 (   2 non-Horn;  13 unit;  12 RR)
%            Number of literals   :   43 (  28 equality)
%            Maximal clause size  :    4 (   1 average)
%            Number of predicates :    2 (   0 propositional; 1-2 arity)
%            Number of functors   :    8 (   5 constant; 0-2 arity)
%            Number of variables  :   38 (   0 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : Used to define a subgroup of index two is a theorem which 
%            says that {for all x, for all y, there exists a z such that 
%            if x and y are both not in the subgroup O, then z is in O and 
%            x*z=y} if & only if {O has index 2 in G}. This z is named 
%            by the skolem function i(x,y). Explanation: If O is of index 
%            two in G, then there are exactly two cosets, namely O and 
%            uO for some u not in O. If both of x and y are not in O, then 
%            they are in uO. But then xO=yO, which implies that there 
%            exists some z in O such that x*z=y. If the condition holds 
%            that {for all x, for all y, there exists a z such that 
%            if x and y are both not in the subgroup O, then z is in O and 
%            x*z=y}, then xO=yO for all x,y not in O, which implies that 
%            there are at most two cosets; and there must be at least two, 
%            namely O and xO, since x is not in O. Therefore O must 
%            be of index two.
%          : element_in_O2(A,B) is A^-1.B. The axioms with element_in_O2 
%            force index 2.
% Bugfixes : v1.0.1 - Duplicate axioms multiply_inverse_left and 
%            multiply_inverse_right removed.
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%----Include the axioms for group theory in equality form 
include('Axioms/GRP004-0.ax').
%----Include the subgroup axioms in equality formulation 
include('Axioms/GRP004-1.ax').
%--------------------------------------------------------------------------
%----Redundant two axioms
input_clause(right_identity,axiom,
    [++equal(multiply(X,identity),X)]).

input_clause(right_inverse,axiom,
    [++equal(multiply(X,inverse(X)),identity)]).

%----The next two clauses are previously established lemmas 
input_clause(inverse_inverse,axiom,
    [++equal(inverse(inverse(X)),X)]).

input_clause(inverse_of_identity,axiom,
    [++equal(inverse(identity),identity)]).

%----This axiom is dependent 
input_clause(identity_in_O2,axiom,
    [++subgroup_member(identity)]).

%----Definition of a subgroup of index 2 
input_clause(an_element_in_O2,axiom,
    [++subgroup_member(X),
     ++subgroup_member(Y),
     ++subgroup_member(element_in_O2(X,Y))]).

input_clause(property_of_O2,axiom,
    [++subgroup_member(X),
     ++subgroup_member(Y),
     ++equal(multiply(X,element_in_O2(X,Y)),Y)]).

input_clause(element_in_O2_substitutivity1,axiom,
    [--equal(A,B),
     ++equal(element_in_O2(A,C),element_in_O2(B,C))]).

input_clause(element_in_O2_substitutivity2,axiom,
    [--equal(D,E),
     ++equal(element_in_O2(F,D),element_in_O2(F,E))]).

%----Denial of theorem 
input_clause(b_in_O2,conjecture,
    [++subgroup_member(b)]).

input_clause(b_times_a_inverse_is_c,conjecture,
    [++equal(multiply(b,inverse(a)),c)]).

input_clause(a_times_c_is_d,conjecture,
    [++equal(multiply(a,c),d)]).

input_clause(prove_d_in_O2,conjecture,
    [--subgroup_member(d)]).
%--------------------------------------------------------------------------
