%--------------------------------------------------------------------------
% File     : GRP167-5 : TPTP v2.2.0. Bugfixed v1.2.1.
% Domain   : Group Theory (Lattice Ordered)
% Problem  : Product of positive and negative parts
% Version  : [Fuc94] (equality) axioms : Augmented.
% English  : Each element in a lattice ordered group can be stated as a
%            product of it's positive and it's negative part.

% Refs     : [Fuc94] Fuchs (1994), The Application of Goal-Orientated Heuri
%          : [Sch95] Schulz (1995), Explanation Based Learning for Distribu
%          : [Dah95] Dahn (1995), Email to G. Sutcliffe
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.33 v2.2.0, 0.43 v2.1.0, 0.20 v2.0.0
% Syntax   : Number of clauses    :   33 (   0 non-Horn;  22 unit;   6 RR)
%            Number of literals   :   45 (  45 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :    8 (   2 constant; 0-2 arity)
%            Number of variables  :   73 (   2 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : ORDERING LPO inverse > greatest_lower_bound >
%            least_upper_bound > product > negative_part > positive_part > 
%            identity > a
%          : This is a standardized version of the problem that appears in
%            [Sch95].
%          : [Dah95] suggested the addition of p10 as a useful lemma.
% Bugfixes : v1.2.1 - Duplicate axioms in GRP004-2.ax removed.
%          : v1.2.1 - Clause p10 fixed.
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include equality group theory axioms 
include('Axioms/GRP004-0.ax').
%----Include Lattice ordered group (equality) axioms
include('Axioms/GRP004-2.ax').
%--------------------------------------------------------------------------
input_clause(negative_part_substitution_1,axiom,
    [--equal(A,B),
     ++equal(negative_part(A),negative_part(B))]).

input_clause(positive_part_substitution_1,axiom,
    [--equal(A,B),
     ++equal(positive_part(A),positive_part(B))]).

%----Extra lemma
input_clause(p10,axiom,
    [++equal(inverse(least_upper_bound(A,B)),greatest_lower_bound(
inverse(A),inverse(B)))]).

input_clause(lat4_1,axiom,
    [++equal(positive_part(X),least_upper_bound(X,identity))]).

input_clause(lat4_2,axiom,
    [++equal(negative_part(X),greatest_lower_bound(X,identity))]).

input_clause(lat4_3,axiom,
    [++equal(least_upper_bound(X,greatest_lower_bound(Y,Z)),
greatest_lower_bound(least_upper_bound(X,Y),least_upper_bound(X,Z)))]).

input_clause(lat4_4,axiom,
    [++equal(greatest_lower_bound(X,least_upper_bound(Y,Z)),
least_upper_bound(greatest_lower_bound(X,Y),greatest_lower_bound(X,Z)))]).

input_clause(prove_lat4,conjecture,
    [--equal(a,multiply(positive_part(a),negative_part(a)))]).
%--------------------------------------------------------------------------
