%--------------------------------------------------------------------------
% File     : LAT025-1 : TPTP v2.2.0. Released v2.2.0.
% Domain   : Lattice Theory (Ternary Near Lattices)
% Problem  : Non-uniqueness of meet (dually join) in TNL
% Version  : [MP96] (equality) axioms.
% English  : Let's say we have a ternary near-lattice (TNL) with two meet
%            operations, say meet1 and meet2.  In other words, {join,meet1}
%            and {join,meet2} are TNLs.  Are the two meets necessarily
%            the same?  No, they aren't.  Here is a counterexample.

% Refs     : [McC98] McCune (1998), Email to G. Sutcliffe
%          : [MP96]  McCune & Padmanabhan (1996), Automated Deduction in Eq
% Source   : [McC98]
% Names    : TNL-2 [MP96]

% Status   : satisfiable
% Rating   : ? v2.2.0
% Syntax   : Number of clauses    :   24 (   0 non-Horn;  16 unit;   3 RR)
%            Number of literals   :   33 (  33 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :    5 (   2 constant; 0-2 arity)
%            Number of variables  :   53 (  12 singleton)
%            Maximal term depth   :    4 (   1 average)

% Comments : The smallest model has 5 elements.
%--------------------------------------------------------------------------
%----Include axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
%----Substitution axioms
input_clause(join_substitution1,axiom,
    [--equal(D,E),
     ++equal(join(D,F),join(E,F))]).

input_clause(join_substitution2,axiom,
    [--equal(G,H),
     ++equal(join(I,G),join(I,H))]).

input_clause(meet_substitution1,axiom,
    [--equal(J,K),
     ++equal(meet(J,L),meet(K,L))]).

input_clause(meet_substitution2,axiom,
    [--equal(M,N),
     ++equal(meet(O,M),meet(O,N))]).

input_clause(meet2_substitution_1,axiom,
    [--equal(A,B),
     ++equal(meet2(A,C),meet2(B,C))]).

input_clause(meet2_substitution_2,axiom,
    [--equal(A,B),
     ++equal(meet2(C,A),meet2(C,B))]).

%----{join,meet} is a TNL:
input_clause(idempotence_of_meet,axiom,
    [++equal(meet(X,X),X)]).

input_clause(idempotence_of_join,axiom,
    [++equal(join(X,X),X)]).

input_clause(absorption1,axiom,
    [++equal(meet(X,join(X,Y)),X)]).

input_clause(absorption2,axiom,
    [++equal(join(X,meet(X,Y)),X)]).

input_clause(commutativity_of_meet,axiom,
    [++equal(meet(X,Y),meet(Y,X))]).

input_clause(commutativity_of_join,axiom,
    [++equal(join(X,Y),join(Y,X))]).

input_clause(tnl_1,axiom,
    [++equal(join(X,meet(Y,meet(X,Z))),X)]).

input_clause(tnl_2,axiom,
    [++equal(meet(X,join(Y,join(X,Z))),X)]).

%----{join,meet2} is a TNL:
input_clause(idempotence_of_meet2,axiom,
    [++equal(meet2(X,X),X)]).

input_clause(absorption1_2,axiom,
    [++equal(meet2(X,join(X,Y)),X)]).

input_clause(absorption2_2,axiom,
    [++equal(join(X,meet2(X,Y)),X)]).

input_clause(commutativity_of_meet2,axiom,
    [++equal(meet2(X,Y),meet2(Y,X))]).

input_clause(tnl_1_2,axiom,
    [++equal(join(X,meet2(Y,meet2(X,Z))),X)]).

input_clause(tnl_2_2,axiom,
    [++equal(meet2(X,join(Y,join(X,Z))),X)]).

%----Denial of meet=meet2.
input_clause(prove_meets_equal,conjecture,
    [--equal(meet(a,b),meet2(a,b))]).
%--------------------------------------------------------------------------
