%--------------------------------------------------------------------------
% File     : MGT001+1 : TPTP v2.2.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favors organizations with high inertia
% Version  : [PB+94] axioms.
% English  : Selection within populations of organizations in modern
%            societies favours organizations whose structure have high
%            inertia.

% Refs     : [PB+92] Peli et al. (1992), A Logical Approach to Formalizing
%          : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing 
%          : [Kam94] Kamps (1994), Email to G. Sutcliffe
% Source   : [Kam94]
% Names    : THEOREM 1 [PB+92]
%          : T1FOL3 [PB+94]

% Status   : theorem
% Rating   : 0.00 v2.1.0
% Syntax   : Number of formulae    :    7 (   0 unit)
%            Number of atoms       :   48 (   0 equality)
%            Maximal formula depth :   12 (   7 average)
%            Number of connectives :   41 (   0 ~  ;   0  |;  32  &)
%                                         (   2 <=>;   7 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 2-3 arity)
%            Number of functors    :    0 (   0 constant; --- arity)
%            Number of variables   :   45 (   3 singleton;  42 !;   3 ?)
%            Maximal term depth    :    1 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
input_formula(mp1,axiom,(
    ! [X,T] : 
      ( organization(X,T)
     => ? [R] : reliability(X,R,T) )   )).

input_formula(mp2,axiom,(
    ! [X,T] : 
      ( organization(X,T)
     => ? [A] : accountability(X,A,T) )   )).

input_formula(mp3,axiom,(
    ! [X,T] : 
      ( organization(X,T)
     => ? [Rp] : reproducibility(X,Rp,T) )   )).

%----Selection in populations of organizations in modern societies favours
%----forms with high reliability of performance and high levels of
%----accountability.
input_formula(a1_FOL,hypothesis,(
    ! [X,Y,R1,R2,A1,A2,P1,P2,T1,T2] : 
      ( ( organization(X,T1)
        & organization(Y,T2)
        & reliability(X,R1,T1)
        & reliability(Y,R2,T2)
        & accountability(X,A1,T1)
        & accountability(Y,A2,T2)
        & survival_chance(X,P1,T1)
        & survival_chance(Y,P2,T2)
        & greater(R2,R1)
        & greater(A2,A1) )
     => greater(P2,P1) )   )).

%----Reliability and accountability require that organizational structures
%----be highly reproducible.
input_formula(a2_FOL,hypothesis,(
    ! [X,Y,T1,T2,R1,R2,A1,A2,Rp1,Rp2] : 
      ( ( organization(X,T1)
        & organization(Y,T2)
        & reliability(X,R1,T1)
        & reliability(Y,R2,T2)
        & accountability(X,A1,T1)
        & accountability(Y,A2,T2)
        & reproducibility(X,Rp1,T1)
        & reproducibility(Y,Rp2,T2) )
     => ( greater(Rp2,Rp1)
      <=> ( greater(R2,R1)
          & greater(A2,A1) ) ) )   )).

%----High levels of reproducibility of structure generate strong
%----inertial pressures.
input_formula(a3_FOL,hypothesis,(
    ! [X,Y,T1,T2,Rp1,Rp2,I1,I2] : 
      ( ( organization(X,T1)
        & organization(Y,T2)
        & reorganization_free(X,T1,T1)
        & reorganization_free(Y,T2,T2)
        & reproducibility(X,Rp1,T1)
        & reproducibility(Y,Rp2,T2)
        & inertia(X,I1,T1)
        & inertia(Y,I2,T2) )
     => ( greater(Rp2,Rp1)
      <=> greater(I2,I1) ) )   )).

input_formula(t1_FOL,conjecture,(
    ! [X,Y,T1,T2,I1,I2,P1,P2] : 
      ( ( organization(X,T1)
        & organization(Y,T2)
        & reorganization_free(X,T1,T1)
        & reorganization_free(Y,T2,T2)
        & inertia(X,I1,T1)
        & inertia(Y,I2,T2)
        & survival_chance(X,P1,T1)
        & survival_chance(Y,P2,T2)
        & greater(I2,I1) )
     => greater(P2,P1) )   )).
%--------------------------------------------------------------------------
