%--------------------------------------------------------------------------
% File     : MGT034+2 : TPTP v2.2.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favors FMs above EPs until critical point reached
% Version  : [PM93] axioms.
% English  : Selection favors first movers above efficient producers past 
%            the appearance of efficient producers until the critical
%            point is reached. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing
% Source   : [PM93]
% Names    : THEOREM 3 [PM93]
%          : T3 [PB+94]

% Status   : theorem
% Rating   : 0.00 v2.1.0
% Syntax   : Number of formulae    :   53 (   1 unit)
%            Number of atoms       :  159 (  51 equality)
%            Maximal formula depth :    7 (   4 average)
%            Number of connectives :  110 (   4 ~  ;   1  |;  51  &)
%                                         (   3 <=>;  51 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-4 arity)
%            Number of functors    :   11 (   3 constant; 0-2 arity)
%            Number of variables   :  143 (   0 singleton; 143 !;   0 ?)
%            Maximal term depth    :    3 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(critical_point_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(critical_point(A),critical_point(B)) )   )).

input_formula(difference_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(difference(A,C),difference(B,C)) )   )).

input_formula(difference_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(difference(C,A),difference(C,B)) )   )).

input_formula(disbanding_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(A,C),disbanding_rate(B,C)) )   )).

input_formula(disbanding_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(C,A),disbanding_rate(C,B)) )   )).

input_formula(founding_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(founding_rate(A,C),founding_rate(B,C)) )   )).

input_formula(founding_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(founding_rate(C,A),founding_rate(C,B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(start_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(start_time(A),start_time(B)) )   )).

input_formula(decreases_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & decreases(A) )
     => decreases(B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(selection_favors_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(A,C,D) )
     => selection_favors(B,C,D) )   )).

input_formula(selection_favors_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,A,D) )
     => selection_favors(C,B,D) )   )).

input_formula(selection_favors_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,D,A) )
     => selection_favors(C,D,B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP1. Selection favors subpopulations with higher growth rates.
input_formula(mp1_high_growth_rates,axiom,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulations(S1,S2,E,T)
        & greater(growth_rate(S2,T),growth_rate(S1,T)) )
     => selection_favors(S2,S1,T) )   )).

%----L3. The difference between the disbanding rates of first movers and
%----efficient producers does not decrease.
input_formula(l3,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )   )).

%----MP. If the environment contains a critical point, then FM and EP are
%----present at this time.
input_formula(mp_critical_point_means_FM_and_EP,axiom,(
    ! [E] : 
      ( ( environment(E)
        & in_environment(E,critical_point(E)) )
     => subpopulations(first_movers,efficient_producers,E,
critical_point(E)) )   )).

%----MP. FM and EP are present when EP appear in the environment.
input_formula(mp_FM_and_EP_when_EP_appears,axiom,(
    ! [E] : 
      ( ( environment(E)
        & in_environment(E,appear(efficient_producers,E)) )
     => subpopulations(first_movers,efficient_producers,E,
appear(efficient_producers,E)) )   )).

%----MP. If the difference between the founding rates of FM and EP 
%----decreases and the difference between their disbanding rates does 
%----not decrease, then the difference between the growth rates decreases.
input_formula(mp_difference_between_founding_rates,axiom,(
    ! [T] : 
      ( ( decreases(difference(founding_rate(first_movers,T),
founding_rate(efficient_producers,T)))
        & ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )
     => decreases(difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T))) )   )).

%----MP. If function "f" is decreasing until to, and it is not negative at
%----"to, then its value is positive before "to".
%----INSTANTIATION: f(x) = (growth_rate(first_movers,x) -
%----growth_rate(efficient_producers,x)
input_formula(mp_decreasing_function,axiom,(
    ! [E,T,To] : 
      ( ( environment(E)
        & in_environment(E,To)
        & greater_or_equal(difference(growth_rate(first_movers,To),
growth_rate(efficient_producers,To)),zero)
        & greater_or_equal(T,appear(efficient_producers,E))
        & greater(To,T) )
     => ( decreases(difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T)))
       => greater(difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T)),zero) ) )   )).

%----MP. The difference between the growth rates of first movers and
%----efficient producers is negative, if and only if, the growth rate of
%----efficient producers is higher.
input_formula(mp_negative_growth_rate_difference,axiom,(
    ! [T] : 
      ( greater(zero,difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T)))
    <=> greater(growth_rate(efficient_producers,T),growth_rate(first_movers,
T)) )   )).

%----MP. The difference between the growth rates of first movers and
%----efficient producers is positive, if and only if, the growth rate of
%----first movers is higher.
input_formula(mp_positive_growth_rate_difference,axiom,(
    ! [T] : 
      ( greater(difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T)),zero)
    <=> greater(growth_rate(first_movers,T),growth_rate(efficient_producers,
T)) )   )).

%----MP. The durations of environments are time-intervals.
input_formula(mp_durations_are_time_intervals,axiom,(
    ! [E,T1,T2,T] : 
      ( ( environment(E)
        & in_environment(E,T1)
        & in_environment(E,T2)
        & greater_or_equal(T2,T)
        & greater_or_equal(T,T1) )
     => in_environment(E,T) )   )).

%----MP. The opening time of the environment belongs to the environment's
%----duration.
input_formula(mp_opening_time_in_duration,axiom,(
    ! [E] : 
      ( environment(E)
     => in_environment(E,start_time(E)) )   )).

%----MP. FM cannot appear in an environment before it opens.
input_formula(mp_no_FM_before_opening,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(appear(first_movers,E),start_time(E)) )   )).

%----MP. If the critical point occurs in the environment, then all the 
%----time-points between the appearence of efficient producers and the 
%----critical point occur in the environnment.
input_formula(mp_critical_time_points,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,critical_point(E))
        & greater_or_equal(T,appear(efficient_producers,E))
        & greater(critical_point(E),T) )
     => in_environment(E,T) )   )).

%----MP.  If the number of both first movers and efficient producers is
%----positive in an environment, then the population in this environment 
%----contains a first mover and an efficient producer subpopulation.
input_formula(mp_contains_FM_and_EP,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(cardinality_at_time(first_movers,T),zero)
        & greater(cardinality_at_time(efficient_producers,T),zero) )
     => subpopulations(first_movers,efficient_producers,E,T) )   )).

%----MP. The "subpopulation" predicate is symmetric: if FM and EP are 
%----non-empty subpopulations in E, then EP and FM are also non-empty 
%----subpopulations in E.
input_formula(mp_symmetry_of_subpopulations,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => subpopulations(efficient_producers,first_movers,E,T) )   )).

%----MP. If FM and EP have members in an environment at a certain point of
%----time, then EP's appearence time is already passed.
input_formula(mp_FM_and_EP_members_EP_appeared,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => greater_or_equal(T,appear(efficient_producers,E)) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----MP. on growth rates
input_formula(mp_relationship_of_growth_rates,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T)
        & ~ greater(zero,difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T))) )
     => greater_or_equal(difference(growth_rate(first_movers,T),
growth_rate(efficient_producers,T)),zero) )   )).

%----D1(<=). If a time-point is the critical point of the environment, then
%----it is the earliest time past which the growth rate of efficient
%----producers permanently exceeds growth rate of first movers.
input_formula(d1,hypothesis,(
    ! [E,Tc] : 
      ( ( environment(E)
        & equal(Tc,critical_point(E)) )
     => ( ~ greater(growth_rate(efficient_producers,Tc),
growth_rate(first_movers,Tc))
        & ! [T] : 
            ( ( subpopulations(first_movers,efficient_producers,E,T)
              & greater(T,Tc) )
           => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).

%----A10. If FM and EP are present in the environment at time-points t1
%----and t2, then they are present during the time-interval between 
%----t1 and t2.
input_formula(a10,hypothesis,(
    ! [E,T1,T2,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T1)
        & subpopulations(first_movers,efficient_producers,E,T2)
        & greater_or_equal(T,T1)
        & greater_or_equal(T2,T) )
     => subpopulations(first_movers,efficient_producers,E,T) )   )).

%----A12. The difference between the founding rates of first movers and
%----efficient producers decreases with time.
input_formula(a12,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => decreases(difference(founding_rate(first_movers,T),
founding_rate(efficient_producers,T))) )   )).

%----GOAL: T3. Selection favors first movers above efficient producers
%----between the appearence of efficient producers and the critical point.
input_formula(prove_t3,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,critical_point(E))
        & greater_or_equal(T,appear(efficient_producers,E))
        & greater(critical_point(E),T) )
     => selection_favors(first_movers,efficient_producers,T) )   )).
%--------------------------------------------------------------------------
