%--------------------------------------------------------------------------
% File     : MGT038+1 : TPTP v2.2.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : FMs become extinct in stable environments
% Version  : [PB+94] axioms : Reduced & Augmented > Complete.
% English  : First movers become extinct past a certain point in time 
%            in stable environments. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : 

% Status   : satisfiable
% Rating   : 0.00 v2.1.0
% Syntax   : Number of formulae    :   24 (   2 unit)
%            Number of atoms       :   68 (  25 equality)
%            Maximal formula depth :    6 (   3 average)
%            Number of connectives :   44 (   0 ~  ;   0  |;  22  &)
%                                         (   0 <=>;  22 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-2 arity)
%            Number of functors    :    9 (   7 constant; 0-2 arity)
%            Number of variables   :   57 (   1 singleton;  54 !;   3 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(contracts_from_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & contracts_from(A,C) )
     => contracts_from(B,C) )   )).

input_formula(contracts_from_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & contracts_from(C,A) )
     => contracts_from(C,B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(finite_set_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & finite_set(A) )
     => finite_set(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(stable_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & stable(A) )
     => stable(B) )   )).

%----Problem axioms
%----MP7. The cardinality of the first mover set is always integer.
input_formula(mp7_first_movers_exist,axiom,(
    finite_set(first_movers)   )).

%----MP. First movers appear in stable environments.
input_formula(mp_stable_first_movers,axiom,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => in_environment(E,appear(first_movers,E)) )   )).

%----MP. If a set with finitely many elements always contracts past a
%----certain point of time, then it becomes empty sooner or later.
input_formula(mp_contracting_time,axiom,(
    ! [S,To] : 
      ( ( finite_set(S)
        & contracts_from(To,S) )
     => ? [T2] : 
          ( greater(T2,To)
          & equal(cardinality_at_time(s,t2),zero) ) )   )).

%----MP. Stable environments are long.
input_formula(mp_long_stable_environments,axiom,(
    ! [E,T1,T2] : 
      ( ( environment(E)
        & stable(E)
        & in_environment(E,T1)
        & greater(T2,T1) )
     => in_environment(E,T2) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----L9. The first mover set begins to contract past a certain time in
%----stable environments.
input_formula(l9,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( greater(To,appear(efficient_producers,E))
          & contracts_from(To,first_movers) ) )   )).

%----A13. First movers appear sooner in the environment, than efficient
%----producers.
input_formula(a13,hypothesis,(
    ! [E] : 
      ( environment(E)
     => greater(appear(efficient_producers,e),appear(first_movers,E)) )   )).

%----GOAL: T7. First movers disappear past a certain time after their
%----appearence in stable environments.
input_formula(prove_t7,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & greater(To,appear(first_movers,E))
          & equal(cardinality_at_time(first_movers,to),zero) ) )   )).
%--------------------------------------------------------------------------
