%--------------------------------------------------------------------------
% File     : MGT038+2 : TPTP v2.2.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : FMs become extinct in stable environments
% Version  : [PM93] axioms.
% English  : First movers become extinct past a certain point in time 
%            in stable environments. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing
% Source   : [PM93]
% Names    : THEOREM 7 [PM93]
%          : T7 [PB+94]

% Status   : unknown
% Rating   : 1.00 v2.1.0
% Syntax   : Number of formulae    :   41 (   2 unit)
%            Number of atoms       :  135 (  39 equality)
%            Maximal formula depth :   10 (   4 average)
%            Number of connectives :   94 (   0 ~  ;   3  |;  48  &)
%                                         (   1 <=>;  42 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    9 (   0 propositional; 1-4 arity)
%            Number of functors    :   11 (   7 constant; 0-2 arity)
%            Number of variables   :  111 (   1 singleton; 106 !;   6 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(equilibrium_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(equilibrium(A),equilibrium(B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(contracts_from_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & contracts_from(A,C) )
     => contracts_from(B,C) )   )).

input_formula(contracts_from_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & contracts_from(C,A) )
     => contracts_from(C,B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(finite_set_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & finite_set(A) )
     => finite_set(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(stable_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & stable(A) )
     => stable(B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP7. The number of the first movers is always a non-negative integer.
input_formula(mp7_first_movers_exist,axiom,(
    finite_set(first_movers)   )).

%----MP. If a set with finitely many elements always contracts past a
%----certain point of time, then it becomes empty sooner or later.
input_formula(mp_contracting_time,axiom,(
    ! [S,To] : 
      ( ( finite_set(S)
        & contracts_from(To,S) )
     => ? [T2] : 
          ( greater(T2,To)
          & equal(cardinality_at_time(s,t2),zero) ) )   )).

%----MP on "contracts from"
input_formula(mp_contracts_from,axiom,(
    ! [E,To] : 
      ( ( environment(E)
        & stable(E)
        & in_environment(E,To)
        & ! [T] : 
            ( ( greater(cardinality_at_time(first_movers,T),zero)
              & greater_or_equal(T,To) )
           => greater(zero,growth_rate(first_movers,T)) ) )
     => contracts_from(To,first_movers) )   )).

%----MP.  If the number of both first movers abd efficient producers is
%----positive in an environment, then the population in this environment 
%----contains a first mover and an efficient producer subpopulation.
input_formula(mp_contains_FM_and_EP,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(cardinality_at_time(first_movers,T),zero)
        & greater(cardinality_at_time(efficient_producers,T),zero) )
     => subpopulations(first_movers,efficient_producers,E,T) )   )).

%----MP. Stable environments are long.
input_formula(mp_long_stable_environments,axiom,(
    ! [E,T1,T2] : 
      ( ( environment(E)
        & stable(E)
        & in_environment(E,T1)
        & greater(T2,T1) )
     => in_environment(E,T2) )   )).

%----MP. First movers appear in stable environments.
input_formula(mp_stable_first_movers,axiom,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => in_environment(E,appear(first_movers,E)) )   )).

%----MP. Efficient producers appear in stable environments.
input_formula(mp_stable_efficient_producers,axiom,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => in_environment(E,appear(efficient_producers,E)) )   )).

%----MP. If first movers have negative growth rate past time t1 in a
%----stable environment, then there is also a time, t2, which is after the
%----appearence of EP,  and FM has negative growth rate past t2.
input_formula(mp_first_movers_negative_growth,axiom,(
    ! [E] : 
      ( ( environment(E)
        & stable(E)
        & ? [T1] : 
            ( in_environment(E,T1)
            & ! [T] : 
                ( ( subpopulations(first_movers,efficient_producers,E,T)
                  & greater_or_equal(T,T1) )
               => greater(zero,growth_rate(first_movers,T)) ) ) )
     => ? [T2] : 
          ( greater(T2,appear(efficient_producers,E))
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,T2) )
             => greater(zero,growth_rate(first_movers,T)) ) ) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. times in environment
input_formula(mp_times_in_environment,axiom,(
    ! [E,T1,T2] : 
      ( ( in_environment(E,T1)
        & in_environment(E,T2) )
     => ( greater(T2,T1)
        | equal(T2,T1)
        | greater(T1,T2) ) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----A3. First movers appear sooner in the environment, than efficient
%----producers.
input_formula(a3,hypothesis,(
    ! [E] : 
      ( environment(E)
     => greater(appear(efficient_producers,e),appear(first_movers,E)) )   )).

%----A5. The state of equilibrium is reached in stable environments.
input_formula(a5,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [T] : 
          ( in_environment(E,T)
          & greater_or_equal(T,equilibrium(E)) ) )   )).

%----T6. Once appeared in an environment, efficient producers do not
%----disappear.
input_formula(t6,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater_or_equal(T,appear(efficient_producers,E)) )
     => greater(cardinality_at_time(efficient_producers,T),zero) )   )).

%----L1. The growth rate of efficient producers exceeds the growth rate of
%----first movers past a certain time in stable environments.
input_formula(l1,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).

%----GOAL: T7. First movers disappear past a certain time after their
%----appearence in stable environments.
input_formula(prove_t7,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & greater(To,appear(first_movers,E))
          & equal(cardinality_at_time(first_movers,to),zero) ) )   )).
%--------------------------------------------------------------------------
