%--------------------------------------------------------------------------
% File     : RNG006-2 : TPTP v2.2.0. Released v1.0.0.
% Domain   : Ring Theory
% Problem  : X*(Y+ -Z) = (X*Y) + -(X*Z)
% Version  : [Wos65] axioms : Reduced & Augmented > Incomplete.
% English  : 

% Refs     : [Wos65] Wos (1965), Unpublished Note
%          : [WM76]  Wilson & Minker (1976), Resolution, Refinements, and S
% Source   : [SPRFN]
% Names    : Problem 25 [Wos65]
%          : wos25 [WM76]

% Status   : unsatisfiable
% Rating   : 0.33 v2.2.0, 0.22 v2.1.0, 0.14 v2.0.0
% Syntax   : Number of clauses    :   36 (   0 non-Horn;  13 unit;  26 RR)
%            Number of literals   :   87 (   0 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-3 arity)
%            Number of functors   :   11 (   8 constant; 0-2 arity)
%            Number of variables  :  114 (   2 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : These are the same axioms as in [MOW76].
%--------------------------------------------------------------------------
%----Include ring theory axioms 
%include('Axioms/RNG001-0.ax').
%--------------------------------------------------------------------------
input_clause(additive_identity1,axiom,
    [++sum(additive_identity,X,X)]).

input_clause(additive_identity2,axiom,
    [++sum(X,additive_identity,X)]).

input_clause(closure_of_multiplication,axiom,
    [++product(X,Y,multiply(X,Y))]).

input_clause(closure_of_addition,axiom,
    [++sum(X,Y,add(X,Y))]).

input_clause(left_inverse,axiom,
    [++sum(additive_inverse(X),X,additive_identity)]).

input_clause(right_inverse,axiom,
    [++sum(X,additive_inverse(X),additive_identity)]).

input_clause(associativity_of_addition1,axiom,
    [--sum(X,Y,U),
     --sum(Y,Z,V),
     --sum(U,Z,W),
     ++sum(X,V,W)]).

input_clause(associativity_of_addition2,axiom,
    [--sum(X,Y,U),
     --sum(Y,Z,V),
     --sum(X,V,W),
     ++sum(U,Z,W)]).

input_clause(commutativity_of_addition,axiom,
    [--sum(X,Y,Z),
     ++sum(Y,X,Z)]).

input_clause(associativity_of_multiplication1,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(U,Z,W),
     ++product(X,V,W)]).

input_clause(associativity_of_multiplication2,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(X,V,W),
     ++product(U,Z,W)]).

input_clause(distributivity1,axiom,
    [--product(X,Y,V1),
     --product(X,Z,V2),
     --sum(Y,Z,V3),
     --product(X,V3,V4),
     ++sum(V1,V2,V4)]).

input_clause(distributivity2,axiom,
    [--product(X,Y,V1),
     --product(X,Z,V2),
     --sum(Y,Z,V3),
     --sum(V1,V2,V4),
     ++product(X,V3,V4)]).

input_clause(distributivity3,axiom,
    [--product(Y,X,V1),
     --product(Z,X,V2),
     --sum(Y,Z,V3),
     --product(V3,X,V4),
     ++sum(V1,V2,V4)]).

input_clause(distributivity4,axiom,
    [--product(Y,X,V1),
     --product(Z,X,V2),
     --sum(Y,Z,V3),
     --sum(V1,V2,V4),
     ++product(V3,X,V4)]).

%-----Equality axioms for operators 
input_clause(addition_is_well_defined,axiom,
    [--sum(X,Y,U),
     --sum(X,Y,V),
     ++equalish(U,V)]).

input_clause(multiplication_is_well_defined,axiom,
    [--product(X,Y,U),
     --product(X,Y,V),
     ++equalish(U,V)]).

%----Equality axioms for additive operator 
input_clause(additive_inverse_substitution,axiom,
    [--equalish(X,Y),
     ++equalish(additive_inverse(X),additive_inverse(Y))]).

input_clause(add_substitution1,axiom,
    [--equalish(X,Y),
     ++equalish(add(X,W),add(Y,W))]).

%----This axiom omited in this version 
%input_clause(add_substitution2,axiom,
%    [--equalish(X,Y),
%     ++equalish(add(W,X),add(W,Y))]).

input_clause(sum_substitution1,axiom,
    [--equalish(X,Y),
     --sum(X,W,Z),
     ++sum(Y,W,Z)]).

input_clause(sum_substitution2,axiom,
    [--equalish(X,Y),
     --sum(W,X,Z),
     ++sum(W,Y,Z)]).

input_clause(sum_substitution3,axiom,
    [--equalish(X,Y),
     --sum(W,Z,X),
     ++sum(W,Z,Y)]).

%----Equality axioms for multiplicative operator 
input_clause(multiply_substitution1,axiom,
    [--equalish(X,Y),
     ++equalish(multiply(X,W),multiply(Y,W))]).

%----This axiom omited in this version 
%input_clause(multiply_substitution2,axiom,
%    [--equalish(X,Y),
%     ++equalish(multiply(W,X),multiply(W,Y))]).

input_clause(product_substitution1,axiom,
    [--equalish(X,Y),
     --product(X,W,Z),
     ++product(Y,W,Z)]).

input_clause(product_substitution2,axiom,
    [--equalish(X,Y),
     --product(W,X,Z),
     ++product(W,Y,Z)]).

input_clause(product_substitution3,axiom,
    [--equalish(X,Y),
     --product(W,Z,X),
     ++product(W,Z,Y)]).

input_clause(multiplicative_identity1,axiom,
    [++product(additive_identity,X,additive_identity)]).

input_clause(multiplicative_identity2,axiom,
    [++product(X,additive_identity,additive_identity)]).

input_clause(product_lemma1,axiom,
    [--product(A,B,C),
     ++product(A,additive_inverse(B),additive_inverse(C))]).

input_clause(product_lemma2,axiom,
    [--product(A,B,C),
     ++product(additive_inverse(A),B,additive_inverse(C))]).

input_clause(product_lemma3,axiom,
    [--product(A,B,C),
     ++product(additive_inverse(A),additive_inverse(B),C)]).

input_clause(b_plus_inverse_c,hypothesis,
    [++sum(b,additive_inverse(c),bS_Ic)]).

input_clause(a_times_b,hypothesis,
    [++product(a,b,aPb)]).

input_clause(a_times_c,hypothesis,
    [++product(a,c,aPc)]).

input_clause(aPb_plus_IaPc,hypothesis,
    [++sum(aPb,additive_inverse(aPc),aPb_S_IaPc)]).

input_clause(prove_a_times_bS_Ic_is_aPb_S__IaPc,conjecture,
    [--product(a,bS_Ic,aPb_S_IaPc)]).
%--------------------------------------------------------------------------
