%--------------------------------------------------------------------------
% File     : RNG010-5 : TPTP v2.2.0. Released v1.0.0.
% Domain   : Ring Theory (Right alternative)
% Problem  : Skew symmetry of the auxilliary function
% Version  : [Ove90] (equality) axioms :
%            Incomplete > Augmented > Incomplete.
% English  : The three Moufang identities imply the skew symmetry 
%            of s(W,X,Y,Z) = (W*X,Y,Z) - X*(W,Y,Z) - (X,Y,Z)*W.
%            Recall that skew symmetry means that the function sign 
%            changes when any two arguments are swapped. This problem 
%            proves the case for swapping the first two arguments.

% Refs     : [Ove90] Overbeek (1990), ATP competition announced at CADE-10
%          : [Ove93] Overbeek (1993), The CADE-11 Competitions: A Personal 
%          : [LM93]  Lusk & McCune (1993), Uniform Strategies: The CADE-11 
%          : [Zha93] Zhang (1993), Automated Proofs of Equality Problems in
% Source   : [Ove90]
% Names    : CADE-11 Competition Eq-9 [Ove90]
%          : THEOREM EQ-9 [LM93]
%          : PROBLEM 9 [Zha93]

% Status   : unknown
% Rating   : 1.00 v2.0.0
% Syntax   : Number of clauses    :   44 (   0 non-Horn;  28 unit;   5 RR)
%            Number of literals   :   61 (  61 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :   11 (   5 constant; 0-4 arity)
%            Number of variables  :  110 (   2 singleton)
%            Maximal term depth   :    6 (   1 average)

% Comments : I copied this directly. I think the Moufang identities may 
%            be wrong. At least they're in another form.
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(add_substitutivity1,axiom,
    [--equal(A,B),
     ++equal(add(A,C),add(B,C))]).

input_clause(add_substitutivity2,axiom,
    [--equal(D,E),
     ++equal(add(F,D),add(F,E))]).

input_clause(additive_inverse_substitutivity1,axiom,
    [--equal(G,H),
     ++equal(additive_inverse(G),additive_inverse(H))]).

input_clause(multiply_substitutivity1,axiom,
    [--equal(I,J),
     ++equal(multiply(I,K),multiply(J,K))]).

input_clause(multiply_substitutivity2,axiom,
    [--equal(L,M),
     ++equal(multiply(N,L),multiply(N,M))]).

input_clause(associator_substitutivity1,axiom,
    [--equal(A,B),
     ++equal(associator(A,C,D),associator(B,C,D))]).

input_clause(associator_substitutivity2,axiom,
    [--equal(E,F),
     ++equal(associator(G,E,H),associator(G,F,H))]).

input_clause(associator_substitutivity3,axiom,
    [--equal(I,J),
     ++equal(associator(K,L,I),associator(K,L,J))]).

input_clause(commutator_substitutivity1,axiom,
    [--equal(M,N),
     ++equal(commutator(M,O),commutator(N,O))]).

input_clause(commutator_substitutivity2,axiom,
    [--equal(P,Q),
     ++equal(commutator(R,P),commutator(R,Q))]).

input_clause(s_substitutivity1,axiom,
    [--equal(S,T),
     ++equal(s(S,U,V,W),s(T,U,V,W))]).

input_clause(s_substitutivity2,axiom,
    [--equal(X,Y),
     ++equal(s(Z,X,A1,B1),s(Z,Y,A1,B1))]).

input_clause(s_substitutivity3,axiom,
    [--equal(C1,D1),
     ++equal(s(E1,F1,C1,G1),s(E1,F1,D1,G1))]).

input_clause(s_substitutivity4,axiom,
    [--equal(H1,I1),
     ++equal(s(J1,K1,L1,H1),s(J1,K1,L1,I1))]).

%----Commutativity of addition 
input_clause(commutative_addition,axiom,
    [++equal(add(X,Y),add(Y,X))]).

%----Associativity of addition 
input_clause(associative_addition,axiom,
    [++equal(add(add(X,Y),Z),add(X,add(Y,Z)))]).

%----Additive identity 
input_clause(right_identity,axiom,
    [++equal(add(X,additive_identity),X)]).

input_clause(left_identity,axiom,
    [++equal(add(additive_identity,X),X)]).

%----Additive inverse 
input_clause(right_additive_inverse,axiom,
    [++equal(add(X,additive_inverse(X)),additive_identity)]).

input_clause(left_additive_inverse,axiom,
    [++equal(add(additive_inverse(X),X),additive_identity)]).

%----Inverse of identity is identity, stupid 
input_clause(additive_inverse_identity,axiom,
    [++equal(additive_inverse(additive_identity),additive_identity)]).

%----Axiom of Overbeek 
input_clause(property_of_inverse_and_add,axiom,
    [++equal(add(X,add(additive_inverse(X),Y)),Y)]).

%----Inverse of (x + y) is additive_inverse(x) + additive_inverse(y), 
input_clause(distribute_additive_inverse,axiom,
    [++equal(additive_inverse(add(X,Y)),add(additive_inverse(X),
additive_inverse(Y)))]).

%----Inverse of additive_inverse of X is X 
input_clause(additive_inverse_additive_inverse,axiom,
    [++equal(additive_inverse(additive_inverse(X)),X)]).

%----Behavior of 0 and the multiplication operation 
input_clause(multiply_additive_id1,axiom,
    [++equal(multiply(X,additive_identity),additive_identity)]).

input_clause(multiply_additive_id2,axiom,
    [++equal(multiply(additive_identity,X),additive_identity)]).

%----Axiom of Overbeek 
input_clause(product_of_inverse,axiom,
    [++equal(multiply(additive_inverse(X),additive_inverse(Y)),
multiply(X,Y))]).

%----x * additive_inverse(y) = additive_inverse (x * y), 
input_clause(multiply_additive_inverse1,axiom,
    [++equal(multiply(X,additive_inverse(Y)),
additive_inverse(multiply(X,Y)))]).

input_clause(multiply_additive_inverse2,axiom,
    [++equal(multiply(additive_inverse(X),Y),
additive_inverse(multiply(X,Y)))]).

%----Distributive property of product over sum 
input_clause(distribute1,axiom,
    [++equal(multiply(X,add(Y,Z)),add(multiply(X,Y),multiply(X,Z)))]).

input_clause(distribute2,axiom,
    [++equal(multiply(add(X,Y),Z),add(multiply(X,Z),multiply(Y,Z)))]).

%----Right alternative law 
input_clause(right_alternative,axiom,
    [++equal(multiply(multiply(X,Y),Y),multiply(X,multiply(Y,Y)))]).

%----Associator 
input_clause(associator,axiom,
    [++equal(associator(X,Y,Z),add(multiply(multiply(X,Y),Z),
additive_inverse(multiply(X,multiply(Y,Z)))))]).

%----Commutator 
input_clause(commutator,axiom,
    [++equal(commutator(X,Y),add(multiply(Y,X),additive_inverse(
multiply(X,Y))))]).

%----Middle associator identity 
input_clause(middle_associator,axiom,
    [++equal(multiply(multiply(associator(X,X,Y),X),associator(X,X,Y)),
additive_identity)]).

%----Left alternative law 
input_clause(left_alternative,axiom,
    [++equal(multiply(multiply(X,X),Y),multiply(X,multiply(X,Y)))]).

%----Definition of s 
input_clause(defines_s,axiom,
    [++equal(s(W,X,Y,Z),add(add(associator(multiply(W,X),Y,Z),
additive_inverse(multiply(X,associator(W,Y,Z)))),additive_inverse(
multiply(associator(X,Y,Z),W))))]).

%----Right Moufang 
input_clause(right_moufang,hypothesis,
    [++equal(multiply(X,multiply(Y,multiply(Z,Y))),
multiply(commutator(multiply(X,Y),Z),Y))]).

%----Left Moufang 
input_clause(left_moufang,hypothesis,
    [++equal(multiply(multiply(Y,multiply(Z,Y)),X),
multiply(Y,commutator(Z,multiply(Y,X))))]).

%----Middle Moufang 
input_clause(middle_moufang,hypothesis,
    [++equal(multiply(multiply(X,Y),multiply(Z,X)),
multiply(multiply(X,multiply(Y,Z)),X))]).

input_clause(prove_skew_symmetry,conjecture,
    [--equal(s(a,b,c,d),additive_inverse(s(b,a,c,d)))]).
%--------------------------------------------------------------------------
