%--------------------------------------------------------------------------
% File     : SET017-7 : TPTP v2.2.0. Bugfixed v2.1.0.
% Domain   : Set Theory
% Problem  : Left cancellation for non-ordered pairs
% Version  : [Qua92] axioms : Augmented.
% English  : 

% Refs     : [Qua92] Quaife (1992), Automated Deduction in von Neumann-Bern
% Source   : [Quaife]
% Names    : UP4 [Qua92]

% Status   : unsatisfiable
% Rating   : 0.17 v2.2.0, 0.33 v2.1.0
% Syntax   : Number of clauses    :  184 (  15 non-Horn;  41 unit; 109 RR)
%            Number of literals   :  377 ( 172 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :   10 (   0 propositional; 1-3 arity)
%            Number of functors   :   41 (  11 constant; 0-3 arity)
%            Number of variables  :  424 (  40 singleton)
%            Maximal term depth   :    6 (   1 average)

% Comments : Preceding lemmas are added.
% Bugfixes : v2.1.0 - Bugfix in SET004-0.ax.
%--------------------------------------------------------------------------
%----Include axioms of equality 
include('Axioms/EQU001-0.ax').
%----Include von Neuman-Bernays-Godel set theory axioms 
include('Axioms/SET004-0.ax').
include('Axioms/SET004-0.eq').
%--------------------------------------------------------------------------
%----Corollaries to Unordered pair axiom. Not in paper, but in email. 
input_clause(corollary_1_to_unordered_pair,axiom,
    [--member(ordered_pair(X,Y),cross_product(U,V)),
     ++member(X,unordered_pair(X,Y))]).

input_clause(corollary_2_to_unordered_pair,axiom,
    [--member(ordered_pair(X,Y),cross_product(U,V)),
     ++member(Y,unordered_pair(X,Y))]).

%----Corollaries to Cartesian product axiom.
input_clause(corollary_1_to_cartesian_product,axiom,
    [--member(ordered_pair(U,V),cross_product(X,Y)),
     ++member(U,universal_class)]).

input_clause(corollary_2_to_cartesian_product,axiom,
    [--member(ordered_pair(U,V),cross_product(X,Y)),
     ++member(V,universal_class)]).

%----                        PARTIAL ORDER.
%----(PO1): reflexive.
input_clause(subclass_is_reflexive,axiom,
    [++subclass(X,X)]).

%----(PO2): antisymmetry is part of A-3.
%----(x < y), (y < x) --> (x = y).

%----(PO3): transitivity.
input_clause(transitivity_of_subclass,axiom,
    [--subclass(X,Y),
     --subclass(Y,Z),
     ++subclass(X,Z)]).

%----                          EQUALITY.
%----(EQ1): equality axiom.
%----a:x:(x = x).
%----This is always an axiom in the TPTP presentation.

%----substitutivity.
%----Not in the paper, and always an axiom in the TPTP presentation 

%----(EQ2): expanded equality definition.
input_clause(equality1,axiom,
    [++equal(X,Y),
     ++member(not_subclass_element(X,Y),X),
     ++member(not_subclass_element(Y,X),Y)]).

input_clause(equality2,axiom,
    [--member(not_subclass_element(X,Y),Y),
     ++equal(X,Y),
     ++member(not_subclass_element(Y,X),Y)]).

input_clause(equality3,axiom,
    [--member(not_subclass_element(Y,X),X),
     ++equal(X,Y),
     ++member(not_subclass_element(X,Y),X)]).

input_clause(equality4,axiom,
    [--member(not_subclass_element(X,Y),Y),
     --member(not_subclass_element(Y,X),X),
     ++equal(X,Y)]).

%----                        SPECIAL CLASSES.
%----(SP1): lemma.
input_clause(special_classes_lemma,axiom,
    [--member(Y,intersection(complement(X),X))]).

%----(SP2):  Existence of O (null class).
%----e:x:a:z:(-(z e x)).
input_clause(existence_of_null_class,axiom,
    [--member(Z,null_class)]).

%----(SP3): O is a subclass of every class.
input_clause(null_class_is_subclass,axiom,
    [++subclass(null_class,X)]).

%----corollary.
input_clause(corollary_of_null_class_is_subclass,axiom,
    [--subclass(X,null_class),
     ++equal(X,null_class)]).

%----(SP4): uniqueness of null class.
input_clause(null_class_is_unique,axiom,
    [++equal(Z,null_class),
     ++member(not_subclass_element(Z,null_class),Z)]).

%----(SP5): O is a set (follows from axiom of infinity).
input_clause(null_class_is_a_set,axiom,
    [++member(null_class,universal_class)]).

%----                      UNORDERED PAIRS.
%----(UP1): unordered pair is commutative.
input_clause(commutativity_of_unordered_pair,axiom,
    [++equal(unordered_pair(X,Y),unordered_pair(Y,X))]).

%----(UP2): if one argument is a proper class, pair contains only the 
%----other. In a slightly different form to the paper 
input_clause(singleton_in_unordered_pair1,axiom,
    [++subclass(singleton(X),unordered_pair(X,Y))]).

input_clause(singleton_in_unordered_pair2,axiom,
    [++subclass(singleton(Y),unordered_pair(X,Y))]).

input_clause(unordered_pair_equals_singleton1,axiom,
    [++member(Y,universal_class),
     ++equal(unordered_pair(X,Y),singleton(X))]).

input_clause(unordered_pair_equals_singleton2,axiom,
    [++member(X,universal_class),
     ++equal(unordered_pair(X,Y),singleton(Y))]).

%----(UP3): if both arguments are proper classes, pair is null. 
input_clause(null_unordered_pair,axiom,
    [++equal(unordered_pair(X,Y),null_class),
     ++member(X,universal_class),
     ++member(Y,universal_class)]).

input_clause(prove_left_cancellation_1,conjecture,
    [++equal(unordered_pair(x,y),unordered_pair(x,z))]).

input_clause(prove_left_cancellation_2,conjecture,
    [++member(ordered_pair(y,z),cross_product(universal_class,
universal_class))]).

input_clause(prove_left_cancellation_3,conjecture,
    [--equal(y,z)]).
%--------------------------------------------------------------------------
